Enum Tovs
#[repr(u8)]pub enum Tovs {
AllAfterTrigger = 0,
EachAfterTrigger = 1,
}Variants
AllAfterTrigger = 0
All oversampled conversions for a channel are done consecutively after a trigger.
EachAfterTrigger = 1
Each oversampled conversion for a channel needs a trigger.
Implementations